import { createRouter, createWebHistory, createWebHashHistory } from 'vue-router';
import { defineAsyncComponent } from 'vue';
import { useMainStore } from "@/stores/store";

const Home = defineAsyncComponent(() => import('@/views/Home.vue'));
const Login = defineAsyncComponent(() => import('@/views/Login.vue'));
const UserProfile = defineAsyncComponent(() => import('@/views/UserProfile.vue'));
const News = defineAsyncComponent(() => import('@/views/News.vue'));
const NewsDetail = defineAsyncComponent(() => import('@/views/NewsDetail.vue'));
const CourseList = defineAsyncComponent(() => import('@/views/CourseList.vue'));
const CourseDetail = defineAsyncComponent(() => import('@/views/CourseDetail.vue'));
const Craft = defineAsyncComponent(() => import('@/views/CollegeGroup/Craft.vue'));
const Generation = defineAsyncComponent(() => import('@/views/CollegeGroup/Generation.vue'));
const Future = defineAsyncComponent(() => import('@/views/CollegeGroup/Future.vue'));
const Repair = defineAsyncComponent(() => import('@/views/CollegeGroup/Repair.vue'));
const Teenager = defineAsyncComponent(() => import('@/views/CollegeGroup/Teenager.vue'));
const Cross = defineAsyncComponent(() => import('@/views/CollegeGroup/Cross.vue'));

const routes = [
  {
    path: '/',
    name: 'Home',
    component: Home,
  },
  {
    path: '/login',
    name: 'Login',
    component: Login,
  },
  {
    path: '/user-profile',
    name: 'UserProfile',
    component: UserProfile,
  },
  {
    path: '/news',
    name: 'News',
    component: News,
  },
  {
    path: '/news/:id',
    name: 'NewsDetail',
    component: NewsDetail
  },
  {
    path: '/course-list',
    name: 'CourseList',
    component: CourseList
  },
  {
    path: '/course-detail/:id',
    name: 'CourseDetail',
    component: CourseDetail
  },
  {
    path: '/college-group/craft',
    name: 'Craft',
    component: Craft
  },
  {
    path: '/college-group/generation',
    name: 'Generation',
    component: Generation
  },
  {
    path: '/college-group/future',
    name: 'Future',
    component: Future
  },
  {
    path: '/college-group/repair',
    name: 'Repair',
    component: Repair
  },
  {
    path: '/college-group/teenager',
    name: 'Teenager',
    component: Teenager
  },
  {
    path: '/college-group/cross',
    name: 'Cross',
    component: Cross
  },
];

const router = createRouter({
  // history: createWebHashHistory(),
  history: createWebHistory(import.meta.env.BASE_URL),
  routes
});

// 檢查登入狀態
router.beforeEach((to, from, next) => {
  const token = localStorage.getItem('token');
  const store = useMainStore();

  if (token) {
    store.setLoginState(true);
    console.log('檢查登入狀態', store.loginState);
  } else {
    store.setLoginState(false);
    console.log('檢查登入狀態', store.loginState);
  }

  next();
});

export default router;